diff --git a/source/distro/doc/user-manual.odt b/source/distro/doc/user-manual.odt
index a990554..67a82c3 100644
Binary files a/source/distro/doc/user-manual.odt and b/source/distro/doc/user-manual.odt differ
diff --git a/source/java/writer2latex/api/ConverterFactory.java b/source/java/writer2latex/api/ConverterFactory.java
index b93a40d..0e01ce0 100644
--- a/source/java/writer2latex/api/ConverterFactory.java
+++ b/source/java/writer2latex/api/ConverterFactory.java
@@ -20,7 +20,7 @@
*
* All Rights Reserved.
*
- * Version 1.2 (2010-04-12)
+ * Version 1.2 (2010-04-16)
*
*/
@@ -33,7 +33,7 @@ public class ConverterFactory {
// Version information
private static final String VERSION = "1.1.2";
- private static final String DATE = "2010-04-12";
+ private static final String DATE = "2010-04-16";
/** Return the Writer2LaTeX version in the form
* (major version).(minor version).(patch level)
diff --git a/source/java/writer2latex/api/ConverterResult.java b/source/java/writer2latex/api/ConverterResult.java
index 31d23c2..af3b96e 100644
--- a/source/java/writer2latex/api/ConverterResult.java
+++ b/source/java/writer2latex/api/ConverterResult.java
@@ -20,7 +20,7 @@
*
* All Rights Reserved.
*
- * Version 1.2 (2010-03-28)
+ * Version 1.2 (2010-04-13)
*
*/
@@ -62,31 +62,49 @@ public interface ConverterResult {
*/
public List getContent();
- /** Get the entry which contains the table of contents
+ /** Get the entry which contains the table page
+ *
+ * @return the entry or null if there is no title page
+ */
+ public ContentEntry getTitlePageFile();
+
+ /** Get the entry which contains the start of the actual text (the first chapter, or simply the start of
+ * the document if there are no headings)
*
* @return the entry
*/
+ public ContentEntry getTextFile();
+
+ /** Get the entry which contains the table of contents
+ *
+ * @return the entry or null if a table of content does not exist
+ */
public ContentEntry getTocFile();
-
-
+
/** Get the entry which contains the list of tables
*
- * @return the entry
+ * @return the entry or null if a list of tables does not exist
*/
public ContentEntry getLotFile();
/** Get the entry which contains the list of figures
*
- * @return the entry
+ * @return the entry or null if a list of figures does not exist
*/
public ContentEntry getLofFile();
/** Get the entry which contains the alphabetical index
*
- * @return the entry
+ * @return the entry or null if an alphabetical index does not exist
*/
public ContentEntry getIndexFile();
+ /** Get the entry which contains the bibliography
+ *
+ * @return the entry or null if a bibliography does not exist
+ */
+ public ContentEntry getBibliographyFile();
+
/** Write all files of the ConverterResult to a directory.
* Subdirectories are created as required by the individual
* OutputFiles.
diff --git a/source/java/writer2latex/base/ConverterResultImpl.java b/source/java/writer2latex/base/ConverterResultImpl.java
index 81db1a9..7cf218a 100644
--- a/source/java/writer2latex/base/ConverterResultImpl.java
+++ b/source/java/writer2latex/base/ConverterResultImpl.java
@@ -20,7 +20,7 @@
*
* All Rights Reserved.
*
-* Version 1.2 (2010-03-28)
+* Version 1.2 (2010-04-13)
*
*/
@@ -46,10 +46,13 @@ public class ConverterResultImpl implements ConverterResult {
private List files;
private List content;
+ private ContentEntry titlePageFile;
+ private ContentEntry textFile;
private ContentEntry tocFile;
private ContentEntry lofFile;
private ContentEntry lotFile;
private ContentEntry indexFile;
+ private ContentEntry bibliographyFile;
private MetaData metaData = null;
@@ -67,10 +70,13 @@ public class ConverterResultImpl implements ConverterResult {
public void reset() {
files = new Vector();
content = new Vector();
+ titlePageFile = null;
+ textFile = null;
tocFile = null;
lofFile = null;
lotFile = null;
indexFile = null;
+ bibliographyFile = null;
metaData = null;
nMasterCount = 0;
}
@@ -119,6 +125,30 @@ public class ConverterResultImpl implements ConverterResult {
return Collections.unmodifiableList(content);
}
+ /** Define the entry which contains the title page
+ *
+ * @param entry the entry
+ */
+ public void setTitlePageFile(ContentEntry entry) {
+ titlePageFile = entry;
+ }
+
+ public ContentEntry getTitlePageFile() {
+ return titlePageFile;
+ }
+
+ /** Define the entry which contains the main text file
+ *
+ * @param entry the entry
+ */
+ public void setTextFile(ContentEntry entry) {
+ textFile = entry;
+ }
+
+ public ContentEntry getTextFile() {
+ return textFile;
+ }
+
/** Define the entry which contains the table of contents
*
* @param entry the entry
@@ -167,6 +197,18 @@ public class ConverterResultImpl implements ConverterResult {
return indexFile;
}
+ /** Define the entry which contains the bibliography
+ *
+ * @param entry the entry
+ */
+ public void setBibliographyFile(ContentEntry entry) {
+ bibliographyFile = entry;
+ }
+
+ public ContentEntry getBibliographyFile() {
+ return bibliographyFile;
+ }
+
/** Set the meta data of this ConverterResult
*
* @param metaData the meta data
diff --git a/source/java/writer2latex/epub/OPFWriter.java b/source/java/writer2latex/epub/OPFWriter.java
index a4c2872..8210409 100644
--- a/source/java/writer2latex/epub/OPFWriter.java
+++ b/source/java/writer2latex/epub/OPFWriter.java
@@ -129,15 +129,13 @@ public class OPFWriter extends NewDOMDocument {
// The guide may contain references to some fundamental structural components
Element guide = contentDOM.createElement("guide");
pack.appendChild(guide);
+ addGuideReference(contentDOM,guide,"title-page",cr.getTitlePageFile());
+ addGuideReference(contentDOM,guide,"text",cr.getTextFile());
addGuideReference(contentDOM,guide,"toc",cr.getTocFile());
addGuideReference(contentDOM,guide,"index",cr.getIndexFile());
addGuideReference(contentDOM,guide,"loi",cr.getLofFile());
addGuideReference(contentDOM,guide,"lot",cr.getLotFile());
- // TODO addGuideReference(contentDOM,guide,"bibliography",cr.getBibliographyile());
- List contents = cr.getContent();
- if (contents.size()>0) {
- addGuideReference(contentDOM,guide,"text",contents.get(0));
- }
+ addGuideReference(contentDOM,guide,"bibliography",cr.getBibliographyFile());
setContentDOM(contentDOM);
}
diff --git a/source/oxt/writer2latex/META-INF/manifest.xml b/source/oxt/writer2latex/META-INF/manifest.xml
index fac029b..5292489 100644
--- a/source/oxt/writer2latex/META-INF/manifest.xml
+++ b/source/oxt/writer2latex/META-INF/manifest.xml
@@ -37,5 +37,9 @@
manifest:full-path="writer2latex.rdb"
manifest:media-type="application/vnd.sun.star.uno-typelibrary;type=RDB"/>
+
+
\ No newline at end of file
diff --git a/source/oxt/writer2latex/W2LDialogs/LaTeXOptions.xdl b/source/oxt/writer2latex/W2LDialogs/LaTeXOptions.xdl
index cb528a4..a74761a 100644
--- a/source/oxt/writer2latex/W2LDialogs/LaTeXOptions.xdl
+++ b/source/oxt/writer2latex/W2LDialogs/LaTeXOptions.xdl
@@ -5,7 +5,7 @@
-
+
@@ -17,7 +17,7 @@
-
+
@@ -28,7 +28,7 @@
-
+
@@ -40,15 +40,15 @@
-
-
-
+
+
+
-
+
-
+
@@ -57,17 +57,17 @@
-
+
-
-
-
-
+
+
+
+
-
+
@@ -75,22 +75,22 @@
-
+
-
-
+
+
-
-
+
+
-
+
-
+
@@ -100,11 +100,12 @@
-
-
-
-
+
+
+
+
+
\ No newline at end of file
diff --git a/source/oxt/writer2latex/help/en/help.tree b/source/oxt/writer2latex/help/en/help.tree
new file mode 100644
index 0000000..80c552c
--- /dev/null
+++ b/source/oxt/writer2latex/help/en/help.tree
@@ -0,0 +1,6 @@
+
+
+
+ LaTeX Export
+
+
diff --git a/source/oxt/writer2latex/help/en/org.openoffice.da.writer2latex.oxt/export.xhp b/source/oxt/writer2latex/help/en/org.openoffice.da.writer2latex.oxt/export.xhp
new file mode 100644
index 0000000..52855fa
--- /dev/null
+++ b/source/oxt/writer2latex/help/en/org.openoffice.da.writer2latex.oxt/export.xhp
@@ -0,0 +1,359 @@
+
+
+
+
+ LaTeX Export
+ org.openoffice.da.writer2latex.oxt/export.xhp
+
+
+
+
+ LaTeX Export
+ Exports the current document in LaTeX 2e format. A LaTeX document can be
+ typeset with the TeX typesetting system.
+
+ Choose File - Export - LaTeX 2e
+
+
+ General
+
+
+ LaTeX format
+ Select the general format for the LaTeX document
+ Conceptually, %PRODUCTNAME Writer and LaTeX are quite different.
+ A LaTeX document is usually based on a certain "document class", that determines the general layout and formatting of the document.
+ In addition the use of several LaTeX packages may change various aspects of the LaTeX document.
+ The result of a conversion into LaTeX will thus depend very much on which
+ LaTeX packages are used and how much formatting it is desired to preserve.
+ Writer2LaTeX offers a number of default formats, all based on the standard LaTeX document class "article".
+ Each of the formats defines the LaTeX packages to use and the handling of formatting.
+
+
+ Ultra-clean article will create a very basic LaTeX article,
+ with almost no formatting preserved.
+
+
+ Clean article will also create a default LaTeX article,
+ but does preserve some basic formatting from the %PRODUCTNAME Writer document, such as boldface, color and hyperlinks.
+
+
+ Default creates a LaTeX article preserving as much formatting
+ as it is possible without any significant deviations from LaTeX standards.
+
+
+ Print optimized on the other hand creates a LaTeX article
+ preserving as much formatting as possible. The result will resemble the %PRODUCTNAME Writer document,
+ but will look slightly different from a standard LaTeX article (and the LaTeX code will be less readable).
+
+
+ Screen optimized (pdf) also creates a LaTeX article preserving
+ most of the formatting, but optimized for screen viewing (using the package pdfscreen) rather than printing.
+
+
+ Custom is a user defined format. To configure the custom format,
+ select Tools - Options - Writer2LaTeX.
+
+
+
+ Expert users can extend the list with further formats using
+ configuration packages. See the documentation on the
+ web site for Writer2LaTeX.
+
+
+ Backend
+ Select the final format of the exported document
+ When processing a LaTeX document, the final result is a document in a certain
+ backend format. The handling of certain aspects of the document, in particular graphics, depends on the backend.
+ With this option you can select the backend format.
+
+
+ Generic will create a LaTeX document that can be processed
+ with any flavour of LaTeX, usually with a file in DVI format as the result. Graphics is not supported with this backend.
+
+
+ Pdf (pdfTeX) will create a LaTeX document that is suitable
+ for processing with pdfLaTeX. Graphics are converted to a format that can be included in pdf files.
+
+
+ Postscript (dvips) will create a LaTeX document that is
+ suitable for generating documents in Postscript format, usually by post processing with dvips.
+ Graphics will be converted to Encapsulated postscript format.
+
+
+ Unspecified will create a LaTeX document with no
+ particular backend in mind. All graphics will be exported in the original format,
+ and it is up to the user to handle them.
+
+
+ If you have selected the format Screen optiomized (pdf), you cannot select
+ the backend, which will always be pdf.
+
+
+ Encoding
+ Select the character encoding of the LaTeX file
+ A LaTeX document is a text file, which always uses a certain character encoding.
+ The character encoding is important if the LaTeX file is going to be edited in a text editor:
+ You should select an encoding that is supported by your text editor. This setting is also important to get optimal support
+ for international characters: If you for example use pdfTeX, searching in the final pdf document will only work for
+ characters supported by the selected character encoding.
+ Currently, Writer2LaTeX supports 8 different encodings which together are suitable for a large number of languages written
+ with either latin, greek or cyrillic letters.
+ The supported character encodings are US ASCII,
+ West European (ISO 8859-1), East European (ISO 8859-2), Latin/Greek (ISO 8859-7),
+ Microsoft East European (Cp1250), Microsoft Cyrillic (Cp1251), Russian (koi8-r)
+ and Unicode (UTF8).
+ If you have selected XeTeX as your backed, the character encoding is always UTF-8.
+ XeTeX is needed for asian (CJK) and bidirectional (CTL) scripts.
+
+
+ Enable multilingual support
+ Check this if your document contains text in more than one language
+ If you check this option, all the language settings in the %PRODUCTNAME Writer
+ document will be exported to LaTeX. Sometimes the language settings in a %PRODUCTNAME Writer document are not correct,
+ so if you have a document that is written in one language only you may want to uncheck this option.
+ This will produce a cleaner LaTeX file because you may avoid a large number of language selections.
+
+
+ Use greek letters as symbols
+ Check this treat greek characters as symbols rather than as text
+ Greek letters used in latin text are often used as symbols, such as the
+ number π or the word γ-radiation. By checking this option, all greek letters used within latin or cyrillic text
+ will be treated as mathematical symbols, which will produce a slightly better result – and also not require that
+ greek text fonts are available in the LaTeX installation. This option has no effect on greek text (provided the language
+ is set correctly in the %PRODUCTNAME Writer document).
+
+
+ Support additional symbols
+ Check this to add support for additonal symbols (e.g. phonetic symbols, smileys)
+ If you select this option (not available if XeTeX is the backend),
+ LaTeX will load some additional packages containing support for various symbols:
+ A better looking euro-symbol, phonetic characters, dingbats and various other
+ symbols and geometric shapes.
+
+ Bibliography
+
+
+ Use BibTeX for bibliography
+ Check this to export the bibliography to BibTeX format
+ Usually the bibliography in a LaTeX document is generated by the companion
+ program BibTeX. If you check this option, all the bibliographic references will be exported to BibTeX format for
+ later processing with the BibTeX program.
+
+
+ BibTeX style
+ Enter the name of a BibTeX style to format the bibliography
+ If you use BibTeX, you should also select a BibTeX style to be used when
+ generating the bibliography. Select one of the predefined styles plain, unsrt, alpha or
+ abbrv or type the name of any BibTeX style which is available
+ in your LaTeX installation.
+
+ Files
+
+
+ Wrap long lines
+ Check this if you want to wrap long lines in the LaTeX file
+ Checking this option wraps long lines in the generated LaTeX file.
+ This enhances the readability if the file is later edited in a text editor. If you use a text editor that wraps
+ lines automatically, you should uncheck this option.
+
+
+ After characters
+ Enter the number of characters after which the lines should be wrapped
+ If you choose to wrap long lines, they will be wrapped as soon as possible
+ after this number of characters.
+
+
+ Split document at linked sections
+ Check this to create a separate LaTeX file for each linked section
+ Checking this option will create separate LaTeX files for sections in
+ the %PRODUCTNAME Writer document with linked content. This can be an advantage if the LaTeX document is later edited
+ in a text editor.
+
+
+ Split document at top level sections
+ Check this to create a separate LaTeX file for all sections that are not nested inside another section
+ Checking this option will create separate LaTeX files for all top level
+ sections in the %PRODUCTNAME Writer document (but not for nested sections).
+
+
+ Save images in subdirectory
+ Check this to save the documents in a separate subdirectory
+ Writer2LaTeX normally saves images associated with the document in the same
+ directory as the LaTeX document. If the document contains a large number of images it may be more convenient to save
+ the images in a separate subdirectory. This option will create a subdirectory with the same name as the LaTeX document
+ to store the images.
+
+ Special content
+
+
+ Export notes
+ Select how to export notes in the document
+ This option determines how to export notes (also known as annotations)
+ in the %PRODUCTNAME Writer document.
+
+
+ Do not export will ignore the notes.
+
+
+ As comments will export the notes as comments in the LaTeX file.
+ They will not be visible in the final document after processing with LaTeX.
+
+
+ As marginal notes will put the notes in the margin of the document.
+ In this case they will be visible in the final document, but beware that the notes will be lost if the margin
+ is too narrow.
+
+
+ As pdf annotations will export the notes as pdf text
+ annotations. If the pdf viewer supports it, you will be able to read the notes. Adobe Reader displays text annotations
+ with a yellow icon, which allows you to open and read the note. If the document is not processed with pdfTeX,
+ the notes will be converted to marginal notes.
+
+
+
+
+ Export document properties (metadata)
+ Check this if you want to export meta data associated with the document
+ If you check this option, Writer2LaTeX will export the title, author and date
+ of the document as found under File – Properties. Furthermore, if you have chosen pdf as the backend, the title, author,
+ subject and keywords will be exported to the pdf document and will be viewable if the pdf viewer supports it.
+ If the option is not checked, only the title will be exported.
+
+ Figures and tables
+
+
+ Use original image size
+ Select this option to use the original image size (the size specified in the document will be ignored)
+ Often images in a %PRODUCTNAME Writer document are scaled up or down
+ from their original size. Normally the same scaling will be used in the LaTeX document, but if you select this option,
+ the original (unscaled) image size will be used.
+
+
+ Optimize simple tables
+ Check this to optimize the width of tables
+ Normally Writer2LaTeX will generate tables with the same column widths
+ as in the original document. For tables with simple content it may be more desirable to create tables which are as
+ narrow as possible, with only one line of text per cell. Compare the table
+
+ If you check this option, Writer2LaTeX will try to optimize tables.
+
+
+ Maximum width in characters
+ Enter the maximum width in characters of tables that should have optimized their width
+ If you have chosen to optimize simple tables, you have to specify the maximum
+ width of the table, measured in the number of characters. If you for example set the number to 50, only tables with a total
+ width of 50 or fewer characters will be optimized.
+
+
+ Float tables
+ Check this to allow tables to flow in the document
+ In %PRODUCTNAME Writer you can either choose that the rows of a table must
+ be kept together on one page or that the table may split across page breaks. Keeping a table on one page may be desirable
+ to increase the readability of the table, but it may also leave large white gaps at the bottom of the page.
+ In LaTeX this problem is solved with floating tables: A table can automatically move to another position which fixes
+ the whitespace problem. If you check this option, all tables that are not allowed to break across pages are exported as
+ floating tables.
+
+
+ Float figures
+ Check this to allow figures to flow in the document
+ A similar option is available for figures (graphics, text boxes).
+ If you check this option, figures are converted to floating figures which can move in the document to reduce whitespace.
+ This will not affect figures anchored as character.
+
+
+ Float placement
+ Select placement of floating tables and figures
+ If you choose to let either tables or figures float, use this option to
+ specify the placement of the floats:
+
+
+ Top or bottom of page will place the floats either at
+ the top or the bottom of a page.
+
+
+ Top of page will place floats at the top of a page.
+
+
+ Bottom of page will place floats at the top of a page.
+
+
+ Here or top of page will place floats at their original position,
+ if there is room left on the page, and otherwise at the top of a page.
+
+
+ Here or bottom of page will place floats at their
+ original position, if there is room left on the page, and otherwise at the bottom of a page.
+
+
+ In all cases it might happen that LaTeX creates some special pages which only
+ contains floats. This will usually be the case if there are many floats compared to the amount of text.
+
+ AutoCorrect
+
+
+ Ignore hard page breaks
+ Check this if you don't want to export manual page breaks
+ Hard (or manual) page breaks are often used to optimize page breaks in the
+ final editing of a document. In this case you will probably not want to export these page breaks, as LaTeX creates page
+ breaks that are quite different from the page breaks in %PRODUCTNAME Writer. If you select this option, hard page breaks
+ will be ignored when exporting the document.
+
+
+ Ignore hard line breaks
+ Check this if you don't want to export manual line breaks
+ For similar reasons, you can select this option to ignore hard (manual) line
+ breaks during export.
+
+
+ Ignore empty paragraphs
+ Check this if you don't want to export empty paragraphs
+ Empty paragraphs are sometimes used a simple means to create vertical spacing
+ in %PRODUCTNAME Writer. In a well-structured document, an empty paragraph is probably a mistake. Hence you can select this
+ option to ignore empty paragraphs in the document in the export. If you do not select the option, an empty paragraph is
+ exported as vertical space.
+
+
+ Ignore double spaces
+ Check this if you don't want to export two consecutive space characters
+ For similar reasons you can choose to ignore two or more spaces in a row using
+ this option.
+
+
+
\ No newline at end of file
diff --git a/source/oxt/writer2xhtml/Options.xcs b/source/oxt/writer2xhtml/Options.xcs
index 4204351..0736929 100644
--- a/source/oxt/writer2xhtml/Options.xcs
+++ b/source/oxt/writer2xhtml/Options.xcs
@@ -11,6 +11,7 @@
+
diff --git a/source/oxt/writer2xhtml/W2XDialogs2/Stylesheets.xdl b/source/oxt/writer2xhtml/W2XDialogs2/Stylesheets.xdl
index 9bb1a4c..7afb996 100644
--- a/source/oxt/writer2xhtml/W2XDialogs2/Stylesheets.xdl
+++ b/source/oxt/writer2xhtml/W2XDialogs2/Stylesheets.xdl
@@ -4,13 +4,13 @@
-
+
-
+
diff --git a/source/oxt/xhtml-config-sample/Options.xcu b/source/oxt/xhtml-config-sample/Options.xcu
index 2a18a6a..cbbd13a 100644
--- a/source/oxt/xhtml-config-sample/Options.xcu
+++ b/source/oxt/xhtml-config-sample/Options.xcu
@@ -25,6 +25,10 @@
%origin%/config/sampletemplate.xhtml
+
+
+
+
diff --git a/source/java/writer2latex/xhtml/Converter.java b/source/java/writer2latex/xhtml/Converter.java
index 696557a..ebafb31 100644
--- a/source/java/writer2latex/xhtml/Converter.java
+++ b/source/java/writer2latex/xhtml/Converter.java
@@ -20,7 +20,7 @@
*
* All Rights Reserved.
*
- * Version 1.2 (2010-04-12)
+ * Version 1.2 (2010-04-13)
*
*/
@@ -44,6 +44,7 @@ import org.w3c.dom.NodeList;
import org.w3c.dom.Text;
import writer2latex.api.Config;
+import writer2latex.api.ContentEntry;
import writer2latex.api.ConverterFactory;
//import writer2latex.api.ConverterResult;
import writer2latex.base.ContentEntryImpl;
@@ -209,7 +210,6 @@ public class Converter extends ConverterBase {
}
}
- //NodeList list;
// Traverse the body
Element body = ofr.getContent();
if (ofr.isSpreadsheet()) { tableCv.convertTableContent(body); }
@@ -219,6 +219,21 @@ public class Converter extends ConverterBase {
// Add footnotes and endnotes
textCv.insertFootnotes(htmlDoc.getContentNode());
textCv.insertEndnotes(htmlDoc.getContentNode());
+
+ // Set the title page and text page entries
+ if (converterResult.getContent().isEmpty()) {
+ // No headings in the document: There is no title page and the text page is the first page
+ converterResult.setTextFile(new ContentEntryImpl("Text", 1, outFiles.get(0), null));
+ // We also have to add a toc entry (the ncx file cannot be empty)
+ converterResult.addContentEntry(new ContentEntryImpl("Text", 1, outFiles.get(0), null));
+ }
+ else {
+ // The title page is the first page
+ converterResult.setTitlePageFile(new ContentEntryImpl("Title page", 1, outFiles.get(0), null));
+ // The text page is the one containing the first heading
+ ContentEntry firstHeading = converterResult.getContent().get(0);
+ converterResult.setTextFile(new ContentEntryImpl("Text", 1, firstHeading.getFile(), firstHeading.getTarget()));
+ }
// Resolve links
ListIterator iter = links.listIterator();
@@ -237,8 +252,8 @@ public class Converter extends ConverterBase {
}
}
- // Add included style sheet, if any
- if (styleSheet!=null) {
+ // Add included style sheet, if any - and we are creating OPS content
+ if (bOPS && styleSheet!=null) {
converterResult.addDocument(styleSheet);
}
@@ -529,42 +544,45 @@ public class Converter extends ConverterBase {
meta.setAttribute("content","text/html; charset="+htmlDoc.getEncoding().toLowerCase());
htmlDoc.getHeadNode().appendChild(meta);
}
-
- // "Traditional" meta data
- //createMeta("generator","Writer2LaTeX "+Misc.VERSION);
- createMeta("description",metaData.getDescription());
- createMeta("keywords",metaData.getKeywords());
+
+ // Add meta data (for EPUB the meta data belongs to the .opf file)
+ if (!bOPS) {
+ // "Traditional" meta data
+ //createMeta("generator","Writer2LaTeX "+Misc.VERSION);
+ createMeta("description",metaData.getDescription());
+ createMeta("keywords",metaData.getKeywords());
- // Dublin core meta data (optional)
- // Format as recommended on dublincore.org
- // Declare meta data profile
- if (config.xhtmlUseDublinCore()) {
- htmlDoc.getHeadNode().setAttribute("profile","http://dublincore.org/documents/dcq-html/");
- // Add link to declare namespace
- Element dclink = htmlDOM.createElement("link");
- dclink.setAttribute("rel","schema.DC");
- dclink.setAttribute("href","http://purl.org/dc/elements/1.1/");
- htmlDoc.getHeadNode().appendChild(dclink);
- // Insert the actual meta data
- createMeta("DC.title",metaData.getTitle());
- // DC.subject actually contains subject+keywords, so we merge them
- String sDCSubject = "";
- if (metaData.getSubject()!=null && metaData.getSubject().length()>0) {
- sDCSubject = metaData.getSubject();
- }
- if (metaData.getKeywords()!=null && metaData.getKeywords().length()>0) {
- if (sDCSubject.length()>0) { sDCSubject+=", "; }
- sDCSubject += metaData.getKeywords();
- }
- createMeta("DC.subject",sDCSubject);
- createMeta("DC.description",metaData.getDescription());
- createMeta("DC.creator",metaData.getCreator());
- createMeta("DC.date",metaData.getDate());
- createMeta("DC.language",metaData.getLanguage());
+ // Dublin core meta data (optional)
+ // Format as recommended on dublincore.org
+ // Declare meta data profile
+ if (config.xhtmlUseDublinCore()) {
+ htmlDoc.getHeadNode().setAttribute("profile","http://dublincore.org/documents/dcq-html/");
+ // Add link to declare namespace
+ Element dclink = htmlDOM.createElement("link");
+ dclink.setAttribute("rel","schema.DC");
+ dclink.setAttribute("href","http://purl.org/dc/elements/1.1/");
+ htmlDoc.getHeadNode().appendChild(dclink);
+ // Insert the actual meta data
+ createMeta("DC.title",metaData.getTitle());
+ // DC.subject actually contains subject+keywords, so we merge them
+ String sDCSubject = "";
+ if (metaData.getSubject()!=null && metaData.getSubject().length()>0) {
+ sDCSubject = metaData.getSubject();
+ }
+ if (metaData.getKeywords()!=null && metaData.getKeywords().length()>0) {
+ if (sDCSubject.length()>0) { sDCSubject+=", "; }
+ sDCSubject += metaData.getKeywords();
+ }
+ createMeta("DC.subject",sDCSubject);
+ createMeta("DC.description",metaData.getDescription());
+ createMeta("DC.creator",metaData.getCreator());
+ createMeta("DC.date",metaData.getDate());
+ createMeta("DC.language",metaData.getLanguage());
+ }
}
- // Add link to stylesheet
- if (config.xhtmlCustomStylesheet().length()>0) {
+ // Add link to stylesheet, if producing nomral XHTML
+ if (!bOPS && config.xhtmlCustomStylesheet().length()>0) {
Element htmlStyle = htmlDOM.createElement("link");
htmlStyle.setAttribute("rel","stylesheet");
htmlStyle.setAttribute("type","text/css");
@@ -583,8 +601,8 @@ public class Converter extends ConverterBase {
}*/
// Note: For single output file, styles are exported to the doc at the end.
- // Add link to included style sheet
- if (styleSheet!=null) {
+ // Add link to included style sheet if producing OPS content
+ if (bOPS && styleSheet!=null) {
Element sty = htmlDOM.createElement("link");
sty.setAttribute("rel", "stylesheet");
sty.setAttribute("type", "text/css");